'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _insertTable = require('./changes/insertTable');

var _insertTable2 = _interopRequireDefault(_insertTable);

var _insertRow = require('./changes/insertRow');

var _insertRow2 = _interopRequireDefault(_insertRow);

var _removeRow = require('./changes/removeRow');

var _removeRow2 = _interopRequireDefault(_removeRow);

var _insertColumn = require('./changes/insertColumn');

var _insertColumn2 = _interopRequireDefault(_insertColumn);

var _removeColumn = require('./changes/removeColumn');

var _removeColumn2 = _interopRequireDefault(_removeColumn);

var _removeTable = require('./changes/removeTable');

var _removeTable2 = _interopRequireDefault(_removeTable);

var _moveSelection = require('./changes/moveSelection');

var _moveSelection2 = _interopRequireDefault(_moveSelection);

var _moveSelectionBy = require('./changes/moveSelectionBy');

var _moveSelectionBy2 = _interopRequireDefault(_moveSelectionBy);

var _setColumnAlign = require('./changes/setColumnAlign');

var _setColumnAlign2 = _interopRequireDefault(_setColumnAlign);

var _isSelectionInTable = require('./utils/isSelectionInTable');

var _isSelectionInTable2 = _interopRequireDefault(_isSelectionInTable);

var _getPosition = require('./utils/getPosition');

var _getPosition2 = _interopRequireDefault(_getPosition);

var _schema = require('./schema/schema');

var _schema2 = _interopRequireDefault(_schema);

var _validateNode = require('./schema/validateNode');

var _validateNode2 = _interopRequireDefault(_validateNode);

var _ALIGN = require('./ALIGN');

var _ALIGN2 = _interopRequireDefault(_ALIGN);

var _options = require('./options');

var _options2 = _interopRequireDefault(_options);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

/**
 * Returns a plugin limited to the validation and normalization part of `slate-edit-table`.
 *
 * Import this function only if you don't care about behavior/rendering and you
 * are only manipulating `Slate.Values` without rendering them.
 */
function schemaPlugin(optionsParam) {
    var opts = new _options2.default(optionsParam);

    return {
        schema: (0, _schema2.default)(opts),
        validateNode: (0, _validateNode2.default)(opts),

        utils: {
            isSelectionInTable: _isSelectionInTable2.default.bind(null, opts),
            getPosition: _getPosition2.default.bind(null, opts)
        },

        changes: {
            insertTable: _insertTable2.default.bind(null, opts),
            insertRow: bindAndScopeChange(opts, _insertRow2.default),
            removeRow: bindAndScopeChange(opts, _removeRow2.default),
            insertColumn: bindAndScopeChange(opts, _insertColumn2.default),
            removeColumn: bindAndScopeChange(opts, _removeColumn2.default),
            removeTable: bindAndScopeChange(opts, _removeTable2.default),
            moveSelection: bindAndScopeChange(opts, _moveSelection2.default),
            moveSelectionBy: bindAndScopeChange(opts, _moveSelectionBy2.default),
            setColumnAlign: bindAndScopeChange(opts, _setColumnAlign2.default)
        }
    };
}

/**
 * Bind a change to given options, and scope it to act only inside a table
 */
function bindAndScopeChange(opts, fn) {
    return function (change) {
        for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
            args[_key - 1] = arguments[_key];
        }

        var value = change.value;


        if (!(0, _isSelectionInTable2.default)(opts, value)) {
            return change;
        }

        // $FlowFixMe
        return fn.apply(undefined, _toConsumableArray([opts, change].concat(args)));
    };
}

// Expose aligns here too
schemaPlugin.ALIGN = _ALIGN2.default;

exports.default = schemaPlugin;